==> guile-2.0.11-3-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/ice-9/hash-table.go <==
GOOF----LE-4-2.0      ] c 4   hW      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  
hash-table	 		g  filenameS	
f  ice-9/hash-table.scm	g  exportsS	g  alist->hash-table	
g  alist->hashq-table	g  alist->hashv-table	g  alist->hashx-table	
 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  define-alist-converter	g  macro	g  $sc-dispatch	 	 	g  any	 	g  
syntax-object	g  define	 g  top	!  	"g  ribcage	#g  dummy	$g  name	%g  
hash-set-proc	&#$% 	'g  m-op9HGQbcnppeQp3Vs$kvGr-9542	('  	)(!! 	*f  l-op9HGQbcnppeQp3Vs$kvGr-9547	+f  l-op9HGQbcnppeQp3Vs$kvGr-9548	,f  l-op9HGQbcnppeQp3Vs$kvGr-9549	-*+, 	."&)- 	/" 	0g  x	10 	2( 	3f  l-op9HGQbcnppeQp3Vs$kvGr-9544	43 	5"124 	6!./5 	7g  hygiene	87 	968 	:g  alist	;:68 	<; 	=f   Convert ALIST into a hash table.	>=68 	?g  let	@?68 	Ag  table	BA68 	Cg  make-hash-table	DC68 	ED 	FBE 	GF 	Hg  for-each	IH68 	Jg  lambda	KJ68 	Lg  pair	ML68 	NM 	Og  car	PO68 	QPM 	Rg  cdr	SR68 	TSM 	UBQT 	Vg  reverse	WV68 	XW; 	YX 	ZB 	[g  syntax-violation	\[ 	][ 	^f  -source expression failed to match any pattern	_g  	hash-set!	`g  
hashq-set!	ag  
hashv-set!	bg  
hashx-set!C 5    hx  x   ]4	
5 4 >  "  G   49<>@GIKNUYZ  h0   Z   ]	 
 C      R       g  dummy
		* g  name		* g  
hash-set-proc			*  		*	   C]^       h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/hash-table.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  nameg  
hash-set-proc   C5RCH_        h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	!
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	!
 		*  g  nameg  alist->hash-tableg  
documentationf   Convert ALIST into a hash table. CRCH`  h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	"
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	"
 		*  g  nameg  alist->hashq-tableg  
documentationf   Convert ALIST into a hash table. C
RCHa h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	#
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	#
 		*  g  nameg  alist->hashv-tableg  
documentationf   Convert ALIST into a hash table. CRCHb h   r   ]LLL   6      j       g  pair
		  g  filenamef  ice-9/hash-table.scm
	)		
	*	-		*	8		*	 		   CV h0   5  ]45 4 O 45>  "  G  C  -      g  hash
		. g  assoc		. g  alist			. g  table			.  g  filenamef  ice-9/hash-table.scm
	%
		(			(		
	)			+		#	)	 		.	  g  nameg  alist->hashx-tableg  
documentationf  FConvert ALIST into a hash table with custom HASH and ASSOC
procedures. CRC      p       g  m
		(  g  filenamef  ice-9/hash-table.scm		
[	!
	"
\	#
p	%
 	r
   C6 

==> guile-2.0.11-4-armv6h.pkg.tar.xz: usr/lib/guile/2.0/ccache/ice-9/hash-table.go <==
GOOF----LE-4-2.0      ] c 4   hW      ] g  guile	 	g  define-module*	 	 	g  ice-9	g  
hash-table	 		g  filenameS	
f  ice-9/hash-table.scm	g  exportsS	g  alist->hash-table	
g  alist->hashq-table	g  alist->hashv-table	g  alist->hashx-table	
 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  define-alist-converter	g  macro	g  $sc-dispatch	 	 	g  any	 	g  
syntax-object	g  define	 g  top	!  	"g  ribcage	#g  dummy	$g  name	%g  
hash-set-proc	&#$% 	'g  m-gq7dnO$u8gKCapnyeDy8Y3-9542	('  	)(!! 	*f  l-gq7dnO$u8gKCapnyeDy8Y3-9547	+f  l-gq7dnO$u8gKCapnyeDy8Y3-9548	,f  l-gq7dnO$u8gKCapnyeDy8Y3-9549	-*+, 	."&)- 	/" 	0g  x	10 	2( 	3f  l-gq7dnO$u8gKCapnyeDy8Y3-9544	43 	5"124 	6!./5 	7g  hygiene	87 	968 	:g  alist	;:68 	<; 	=f   Convert ALIST into a hash table.	>=68 	?g  let	@?68 	Ag  table	BA68 	Cg  make-hash-table	DC68 	ED 	FBE 	GF 	Hg  for-each	IH68 	Jg  lambda	KJ68 	Lg  pair	ML68 	NM 	Og  car	PO68 	QPM 	Rg  cdr	SR68 	TSM 	UBQT 	Vg  reverse	WV68 	XW; 	YX 	ZB 	[g  syntax-violation	\[ 	][ 	^f  -source expression failed to match any pattern	_g  	hash-set!	`g  
hashq-set!	ag  
hashv-set!	bg  
hashx-set!C 5    hx  x   ]4	
5 4 >  "  G   49<>@GIKNUYZ  h0   Z   ]	 
 C      R       g  dummy
		* g  name		* g  
hash-set-proc			*  		*	   C]^       h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  ice-9/hash-table.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  nameg  
hash-set-proc   C5RCH_        h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	!
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	!
 		*  g  nameg  alist->hash-tableg  
documentationf   Convert ALIST into a hash table. CRCH`  h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	"
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	"
 		*  g  nameg  alist->hashq-tableg  
documentationf   Convert ALIST into a hash table. C
RCHa h   Y   ]L   6  Q       g  pair
		  g  filenamef  ice-9/hash-table.scm
	#
 		   CV  h0      ]	45 4O 4 5>  "  G  C             g  alist
		* g  table		*  g  filenamef  ice-9/hash-table.scm
	#
 		*  g  nameg  alist->hashv-tableg  
documentationf   Convert ALIST into a hash table. CRCHb h   r   ]LLL   6      j       g  pair
		  g  filenamef  ice-9/hash-table.scm
	)		
	*	-		*	8		*	 		   CV h0   5  ]45 4 O 45>  "  G  C  -      g  hash
		. g  assoc		. g  alist			. g  table			.  g  filenamef  ice-9/hash-table.scm
	%
		(			(		
	)			+		#	)	 		.	  g  nameg  alist->hashx-tableg  
documentationf  FConvert ALIST into a hash table with custom HASH and ASSOC
procedures. CRC      p       g  m
		(  g  filenamef  ice-9/hash-table.scm		
[	!
	"
\	#
p	%
 	r
   C6 
